Module database

Module database 

EUROCONTROL airway database handling.

This module provides functionality to load and query an airway database

Structs

AirwayDatabase
A compiled EUROCONTROL navigational database for querying routes and procedures.
ResolvedRoute
A complete flight route decomposed into segments with geographic and altitude/speed constraints.
ResolvedRouteSegment
A single segment of a resolved route between two waypoints.

Enums

ResolvedPoint
A resolved waypoint on a flight route, resolved to a specific geographic type.