FaaOpenData

Struct FaaOpenData 

pub struct FaaOpenData {
    pub ats_routes: Vec<FaaFeature>,
    pub designated_points: Vec<FaaFeature>,
    pub navaid_components: Vec<FaaFeature>,
    pub airspace_boundary: Vec<FaaFeature>,
    pub class_airspace: Vec<FaaFeature>,
    pub special_use_airspace: Vec<FaaFeature>,
    pub route_airspace: Vec<FaaFeature>,
    pub prohibited_airspace: Vec<FaaFeature>,
}
Complete collection of FAA OpenData from ArcGIS, including routes and airspace.

This struct aggregates all major FAA navigational and airspace datasets from the ArcGIS Open Data platform, which are sourced from the National Airspace System (NAS) and published by the FAA. Each field contains GeoJSON features for a specific category of navigational or regulatory entity.

Fields

  • ats_routes: Automatic Terminal System (ATS) routes (airways like “J500”, “L738”)
  • designated_points: Published waypoints and fixes (e.g., “NERTY”, “ELCOB”)
  • navaid_components: Radio navigation aids (VOR, NDB, etc.)
  • airspace_boundary: Boundaries of Class A–D airspace, TRSAs, MOAs
  • class_airspace: Controlled airspace classification zones
  • special_use_airspace: Military Operations Areas (MOAs), restricted areas, etc.
  • route_airspace: Airspace corridors and flight corridors
  • prohibited_airspace: No-fly zones around sensitive locations

Example

let all_data = parse_all_faa_open_data()?;
println!("ATS routes: {}", all_data.ats_routes.len());
println!("Designated points: {}", all_data.designated_points.len());

Fields

ats_routes: Vec<FaaFeature>designated_points: Vec<FaaFeature>navaid_components: Vec<FaaFeature>airspace_boundary: Vec<FaaFeature>class_airspace: Vec<FaaFeature>special_use_airspace: Vec<FaaFeature>route_airspace: Vec<FaaFeature>prohibited_airspace: Vec<FaaFeature>