NatTrack

Struct NatTrack 

pub struct NatTrack {
    pub track_id: String,
    pub route_points: Vec<NatPoint>,
    pub east_levels: Vec<u16>,
    pub west_levels: Vec<u16>,
    pub nar_routes: Vec<String>,
    pub validity: Option<String>,
    pub source_center: Option<String>,
}
A single North Atlantic Track with routing, altitude assignments, and metadata.

NAT tracks are published daily and define high-altitude oceanic air routes between North America and Europe. Each track specifies a sequence of waypoints and approved flight levels for eastbound and/or westbound traffic. Tracks are identified by single letters (A–Z).

Fields

  • track_id: Single-letter identifier (e.g., “A”, “B”)
  • route_points: Ordered sequence of waypoints defining the track path
  • east_levels: Approved flight levels for eastbound traffic (FL250–FL510)
  • west_levels: Approved flight levels for westbound traffic (FL250–FL510)
  • nar_routes: Alternate North American region routes or special routing
  • validity: Time window during which track is active (e.g., “0000 TO 0600Z”)
  • source_center: Originating ATC center (e.g., “SHANNON”, “GANDER”)

Fields

track_id: Stringroute_points: Vec<NatPoint>east_levels: Vec<u16>west_levels: Vec<u16>nar_routes: Vec<String>validity: Option<String>source_center: Option<String>

Implementations