Connector

Enum Connector 

pub enum Connector {
Show 13 variants Airway(String), Direct, Sid(String), Star(String), Vfr, Ifr, Oat, Gat, IfpStop, IfpStart, StayTime { minutes: Option<u16>, }, Nat(String), Pts(String),
}
A connector between points (airway or direct)

Variants



Airway(String)

ATS routes (e.g., “UM184”, “L738”, “A308”)

They include A, B, G, H, J, L, M, N, P, Q, R, T, U routes and upper airways like UN, UM, UL, UY, etc.

  • [A-Z]{1,2}[0-9]
  • [A-Z][0-9]{1,3}[A-Z]
  • [A-Z][0-9]{2,3}
  • [A-Z]{3}[0-9]{3} (Turkish type)
  • [A-Z]{3}[0-9]{1,2}
  • [A-Z]{2}[0-9][A-Z]
  • [A-Z]{2}[0-9]{2,3}
  • [A-Z]{4}[0-9]{1,2} (Russian air corridors)
  • [A-Z]{2}[0-9]{2,3}[A-Z]
  • [A-Z][0-9]{3}[A-Z]


Direct

Direct routing (DCT)



Sid(String)

SID (Standard Instrument Departure), can be literal “SID” or a named SID

  • [A-Z]{3}[0-9]{1,2}[A-Z]
  • [A-Z]{5}[0-9]{1,2}
  • [A-Z]{4,6}[0-9][A-Z]
  • [A-Z]{5}[0-9]{2}[A-Z]


Star(String)

STAR (Standard Arrival Route), can be literal “STAR” or a named STAR

  • [A-Z]{3}[0-9]{1,2}[A-Z]
  • [A-Z]{5}[0-9]{1,2}
  • [A-Z]{4,6}[0-9][A-Z]
  • [A-Z]{5}[0-9]{2}[A-Z]


Vfr

VFR indicator: change to Visual Flight Rules



Ifr

IFR indicator: change to Instrument Flight Rules



Oat

OAT indicator: change to Operational Air Traffic (military)



Gat

GAT indicator: change to General Air Traffic



IfpStop

IFPSTOP: CFMU IFPS special, stop IFR handling



IfpStart

IFPSTART: CFMU IFPS special, start IFR handling



StayTime

Stay at current position with optional time

Fields

minutes: Option<u16>


Nat(String)

North Atlantic Track (NAT), e.g. NATA-NATZ, NAT1-NAT9, NATX, etc.

  • NAT[A-Z]
  • NAT[A-Z][0-9]


Pts(String)

Polar Track Structure (PTS) track, e.g. PTS0-PTS9, PTSA-PTSZ

  • PTS[0-9] or PTS[A-Z]