Module database

Module database 

EUROCONTROL airway database handling.

This module provides functionality to load and query an airway database

Structs

AirwayDatabase
An airway database containing navaids, designated points, route segments, and routes.
ResolvedRoute
A resolved route consisting of candidate route segments, based on their name.
ResolvedRouteSegment
A resolved route segment consisting of start and end points. Optionally, altitude and speed constraints can be included, propagated from modifiers.

Enums

ResolvedPoint
A resolved point (based on their name), which can be a navaid, designated point, coordinates, or None.