ResolvedPoint

Enum ResolvedPoint 

pub enum ResolvedPoint {
    AirportHeliport(AirportHeliport),
    Navaid(Navaid),
    DesignatedPoint(DesignatedPoint),
    Coordinates {
        latitude: f64,
        longitude: f64,
    },
    None,
}
A resolved point (based on their name), which can be a navaid, designated point, coordinates, or None.

Variants



AirportHeliport(AirportHeliport)



Navaid(Navaid)



DesignatedPoint(DesignatedPoint)



Coordinates

Fields

latitude: f64
longitude: f64


None

Implementations

Source

impl ResolvedPoint

pub fn from_db(point: &PointReference, db: &AirwayDatabase) -> Self

Resolve a point from the database.

pub fn lookup(name: &str, db: &AirwayDatabase) -> Vec<Self>

Resolve a point by its name from the database.