pub struct AirwayDatabase { /* private fields */ }Expand description
An airway database containing navaids, designated points, route segments, and routes.
Implementations
Sourceimpl AirwayDatabase
impl AirwayDatabase
Sourcepub fn new(path: &Path) -> Result<Self, Box<dyn Error>>
pub fn new(path: &Path) -> Result<Self, Box<dyn Error>>
Load the airway database from the specified directory path.
Sourcepub fn resolve_sid_points(&self, name: &str) -> Vec<ResolvedPoint>
pub fn resolve_sid_points(&self, name: &str) -> Vec<ResolvedPoint>
Resolve SID connecting points by procedure designator.
Sourcepub fn resolve_star_points(&self, name: &str) -> Vec<ResolvedPoint>
pub fn resolve_star_points(&self, name: &str) -> Vec<ResolvedPoint>
Resolve STAR connecting points by procedure designator.
Sourcepub fn resolve_sid_routes(&self, name: &str) -> Vec<ResolvedRoute>
pub fn resolve_sid_routes(&self, name: &str) -> Vec<ResolvedRoute>
Resolve SID procedures by designator as route-like segments.
Sourcepub fn resolve_star_routes(&self, name: &str) -> Vec<ResolvedRoute>
pub fn resolve_star_routes(&self, name: &str) -> Vec<ResolvedRoute>
Resolve STAR procedures by designator as route-like segments.
Sourceimpl AirwayDatabase
impl AirwayDatabase
Sourcepub fn enrich_route(
&self,
elements: Vec<Field15Element>,
) -> Vec<ResolvedRouteSegment>
pub fn enrich_route( &self, elements: Vec<Field15Element>, ) -> Vec<ResolvedRouteSegment>
Enrich a sequence of Field15Elements into resolved route segments. A resolved route segment consists of start and end points, along with optional altitude and speed constraints. All points and airways are resolved against the database.