pub struct ResolvedRouteSegment {
pub start: ResolvedPoint,
pub end: ResolvedPoint,
pub name: Option<String>,
pub altitude: Option<Altitude>,
pub speed: Option<Speed>,
}Expand description
A resolved route segment consisting of start and end points. Optionally, altitude and speed constraints can be included, propagated from modifiers.
Fields
start: ResolvedPointend: ResolvedPointname: Option<String>altitude: Option<Altitude>speed: Option<Speed>Implementations
Sourceimpl ResolvedRouteSegment
impl ResolvedRouteSegment
Sourcepub fn from_db(segment: &RouteSegment, db: &AirwayDatabase) -> Self
pub fn from_db(segment: &RouteSegment, db: &AirwayDatabase) -> Self
Resolve a route segment from the database.