pub struct FaaOpenData {
pub ats_routes: Vec<FaaFeature>,
pub designated_points: Vec<FaaFeature>,
pub navaid_components: Vec<FaaFeature>,
pub airspace_boundary: Vec<FaaFeature>,
pub class_airspace: Vec<FaaFeature>,
pub special_use_airspace: Vec<FaaFeature>,
pub route_airspace: Vec<FaaFeature>,
pub prohibited_airspace: Vec<FaaFeature>,
}Expand description
Complete collection of FAA OpenData from ArcGIS, including routes and airspace.
This struct aggregates all major FAA navigational and airspace datasets from the ArcGIS Open Data platform, which are sourced from the National Airspace System (NAS) and published by the FAA. Each field contains GeoJSON features for a specific category of navigational or regulatory entity.
Fields
ats_routes: Automatic Terminal System (ATS) routes (airways like “J500”, “L738”)designated_points: Published waypoints and fixes (e.g., “NERTY”, “ELCOB”)navaid_components: Radio navigation aids (VOR, NDB, etc.)airspace_boundary: Boundaries of Class A–D airspace, TRSAs, MOAsclass_airspace: Controlled airspace classification zonesspecial_use_airspace: Military Operations Areas (MOAs), restricted areas, etc.route_airspace: Airspace corridors and flight corridorsprohibited_airspace: No-fly zones around sensitive locations
Example
ⓘ
let all_data = parse_all_faa_open_data()?;
println!("ATS routes: {}", all_data.ats_routes.len());
println!("Designated points: {}", all_data.designated_points.len());Fields
ats_routes: Vec<FaaFeature>designated_points: Vec<FaaFeature>airspace_boundary: Vec<FaaFeature>class_airspace: Vec<FaaFeature>special_use_airspace: Vec<FaaFeature>route_airspace: Vec<FaaFeature>prohibited_airspace: Vec<FaaFeature>Trait Implementations
Sourceimpl Clone for FaaOpenData
impl Clone for FaaOpenData
Sourcefn clone(&self) -> FaaOpenData
fn clone(&self) -> FaaOpenData
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FaaOpenData
impl Debug for FaaOpenData
Sourceimpl Default for FaaOpenData
impl Default for FaaOpenData
Sourcefn default() -> FaaOpenData
fn default() -> FaaOpenData
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for FaaOpenData
impl<'de> Deserialize<'de> for FaaOpenData
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more